Development
===========

Report bugs and feature requests on the `Issue Tracker <https://github.com/cdelker/schemdraw/issues>`_.

Code contributions are welcome, especially with new circuit elements (and we'd be happy to expand beyond electrical elements too). To contribute code, please fork the `source code repository <https://github.com/cdelker/schemdraw/>`_ and issue a pull request. Make sure to include any new elements somewhere in the test Jupyter notebooks and in the documentation.

- `Source Code <https://github.com/cdelker/schemdraw>`_

|


----------

Want to support Schemdraw development? Need more circuit examples? Pick up the Schemdraw Examples Pack on buymeacoffee.com:

.. raw:: html

    <a href="https://www.buymeacoffee.com/cdelker/e/55648" target="_blank"><img src="https://cdn.buymeacoffee.com/buttons/v2/default-yellow.png" alt="Buy Me A Coffee" style="height: 60px !important;width: 217px !important;" ></a>
